@@ -4,7 +4,7 @@
  * A little RPN (Reverse Polish Notation) calculator, rudimentary          *
  * emulating a HP 28S.                                                     *
  *                                                                         *
- * rpncalc is (c) David Frey et. al., 1993-2004                            *
+ * rpncalc is (c) David Frey et. al., 1993-2004, 2007                      *
  *                                                                         *
  * This program is free software; you can redistribute it and/or modify it *
  * under the terms of the GNU General Public License as published by the   *
@@ -180,7 +180,7 @@ int main(int argc, char *argv[])
     short int l;
     char *args=NULL;    /* entire line  */
 
-    l=0; for(i=optind;i<argc;i++) l += (strlen(argv[optind])+1);
+    l=0; for(i=optind;i<argc;i++) l += (strlen(argv[i])+1);
     args=(char *)xmalloc(l+1);
     strcpy(args, argv[optind]);
     for (i = optind+1; i < argc; i++) {
