@@ -269,7 +269,7 @@ double showstack()
 
                 for (bindigit=0; bindigit<(sizeof(long int)*8); bindigit++) {
                         if (((unsigned long int)value << bindigit) &
-                            (1 << (sizeof(long int)*8) -1)) {
+                            (1 << ((sizeof(long int)*8) -1))) {
                                 printf("1");
                                 binstart = 1;
                         } else {
@@ -302,9 +302,9 @@ double showstack()
                   else if (isnan(value)) { printf("NaN"); }
                   else if ((floor(value) == value) &&
                           ((long int)value <= LONG_MAX)) {
-                    printf("%.0f",value);
+                    printf("%.0lf",value);
                   } else {
-                    printf("%.*g", (digits+1), value);
+                    printf("%.*lg", (digits+1), value);
                   }
                   break;
 
