@@ -38,22 +38,13 @@
 #include <string.h>
 
 #include "utils.h"
-#include "config.h"
 
-#ifdef HAVE_LIBREADLINE
 #include <readline/readline.h>
 #include <readline/history.h>
-#endif
 
-#ifdef HAVE_GETTEXT
 #include <libintl.h>
 
 #define _(String) gettext(String)
-#else
-#define _(String) (String)
-#define textdomain(Domain)
-#define bindtextdomain(Package, Directory)
-#endif
 
 #define LINEFRAGMENT 32
 
@@ -63,8 +54,8 @@ void *xmalloc(size_t size)	/* safe malloc */
 
   ptr=malloc(size);
   if (ptr == NULL) {
-    perror(_("Out of memory!")); 
-    exit(1); 
+    perror(_("Out of memory!"));
+    exit(1);
   }
 
   return ptr;
@@ -74,8 +65,8 @@ void *xrealloc(void *ptr, size_t size)	/* save realloc */
 {
   ptr=realloc(ptr, size);
   if (ptr == NULL) {
-    perror(_("Out of memory!")); 
-    exit(1); 
+    perror(_("Out of memory!"));
+    exit(1);
   }
 
   return ptr;
@@ -89,30 +80,3 @@ char *xstrdup(const char *s)
   strcpy (r, s);
   return (r);
 }
-
-#ifndef HAVE_READLINE
-char *readline(char *prompt)
-/* Read a line of text without imposing an length limit.
-   If we readline support is compiled in, use the readline function. */
-{
-  char *line=NULL;
-  int c, i;
-
-  i=0; line=(char *)xmalloc((size_t)(LINEFRAGMENT+1));
-  while (((c = getc(stdin)) != EOF) && (c != '\n') && (c != '\0')) {
-    if ((i > LINEFRAGMENT) &&  (i % LINEFRAGMENT) == 0) {
-      line=(char *)xrealloc(line,(size_t)(LINEFRAGMENT+1));
-    }
-    line[i]=(char)c; i++;
-  }
-  if ((c != EOF) && (c != '\0')) {
-    line[i]='\0';
-  } else {
-    free(line); 
-    line=NULL;   /* this is readline compatible; 
-		    return NULL when the input line is empty */
-  }
-
-  return line;
-}
-#endif
