@@ -34,7 +34,3 @@
 void *xmalloc(size_t size);
 void *xrealloc(void *ptr, size_t size);
 char *xstrdup(const char *s);
-
-#ifndef HAVE_READLINE
-char *readline(char *prompt);
-#endif
